@@ -1,5 +1,6 @@
 from .version import __version__
 
 __all__ = [
-    'scheduler'
+    'scheduler',
+    'automation',
 ]
