@@ -521,6 +521,10 @@ class SamplingScheduler(object):
         """waits for defined time points in the scheduler to finish"""
         while self.remaining_time_points != 0:
             time.sleep(self.CYCLE_TIME)
+        # if the last triggered time point is not complete, wait for completion
+        last_timepoint = self.last_triggered_time_point
+        if last_timepoint is not None and last_timepoint.complete is False:
+            last_timepoint.wait_for_completion()
 
     def as_dict(self) -> dict:
         """Returns a key: value representation of the instance"""
